gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] [libmicrohttpd] GNU libmicrohttpd branch master updated. d7


From: gitolite
Subject: [GNUnet-SVN] [libmicrohttpd] GNU libmicrohttpd branch master updated. d7392e0882eb7b1cc559d25849204c966a5091ef
Date: Fri, 4 Nov 2016 17:02:59 +0100 (CET)

The branch, master has been updated
       via  d7392e0882eb7b1cc559d25849204c966a5091ef (commit)
      from  ca582a0633be1d06210ad5eefca753f8e87d6211 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit d7392e0882eb7b1cc559d25849204c966a5091ef
Author: Christian Grothoff <address@hidden>
Date:   Fri Nov 4 17:02:56 2016 +0100

    all flags start with MHD_USE_, rename MHD_ALLOW_UPGRADE to MHD_USE_UPGRADE 
for consistency

-----------------------------------------------------------------------

Summary of changes:
 doc/libmicrohttpd.texi            | 2 +-
 src/examples/upgrade_example.c    | 2 +-
 src/include/microhttpd.h          | 4 ++--
 src/microhttpd/connection.c       | 4 ++--
 src/microhttpd/daemon.c           | 6 +++---
 src/microhttpd/response.c         | 2 +-
 src/microhttpd/test_upgrade.c     | 2 +-
 src/microhttpd/test_upgrade_ssl.c | 2 +-
 8 files changed, 12 insertions(+), 12 deletions(-)

diff --git a/doc/libmicrohttpd.texi b/doc/libmicrohttpd.texi
index 730c41f..fac6e63 100644
--- a/doc/libmicrohttpd.texi
+++ b/doc/libmicrohttpd.texi
@@ -591,7 +591,7 @@ Enable TCP_FASTOPEN on the listen socket.  TCP_FASTOPEN is 
currently
 supported on Linux >= 3.6.  On other systems using this option with
 cause @code{MHD_start_daemon} to fail.
 
address@hidden MHD_ALLOW_UPGRADE
address@hidden MHD_USE_UPGRADE
 @cindex upgrade
 This option must be set if you want to upgrade connections
 (via ``101 Switching Protocols'' responses).  This requires MHD to
diff --git a/src/examples/upgrade_example.c b/src/examples/upgrade_example.c
index a917b72..bce6b27 100644
--- a/src/examples/upgrade_example.c
+++ b/src/examples/upgrade_example.c
@@ -275,7 +275,7 @@ main (int argc,
       printf ("%s PORT\n", argv[0]);
       return 1;
     }
-  d = MHD_start_daemon (MHD_ALLOW_UPGRADE | MHD_USE_SELECT_INTERNALLY | 
MHD_USE_DEBUG,
+  d = MHD_start_daemon (MHD_USE_UPGRADE | MHD_USE_SELECT_INTERNALLY | 
MHD_USE_DEBUG,
                         atoi (argv[1]),
                         NULL, NULL,
                         &ahc_echo, NULL,
diff --git a/src/microhttpd/connection.c b/src/microhttpd/connection.c
index 60bf9f6..0c9d1f9 100644
--- a/src/microhttpd/connection.c
+++ b/src/microhttpd/connection.c
@@ -3455,11 +3455,11 @@ MHD_queue_response (struct MHD_Connection *connection,
 #ifdef UPGRADE_SUPPORT
   daemon = connection->daemon;
   if ( (NULL != response->upgrade_handler) &&
-       (0 == (daemon->options & MHD_ALLOW_UPGRADE)) )
+       (0 == (daemon->options & MHD_USE_UPGRADE)) )
     {
 #ifdef HAVE_MESSAGES
       MHD_DLOG (daemon,
-                _("Attempted 'upgrade' connection on daemon without 
MHD_ALLOW_UPGRADE option!\n"));
+                _("Attempted 'upgrade' connection on daemon without 
MHD_USE_UPGRADE option!\n"));
 #endif
       return MHD_NO;
     }
diff --git a/src/microhttpd/daemon.c b/src/microhttpd/daemon.c
index 014e35e..b469c70 100644
--- a/src/microhttpd/daemon.c
+++ b/src/microhttpd/daemon.c
@@ -4639,7 +4639,7 @@ setup_epoll_to_listen (struct MHD_Daemon *daemon)
   if (-1 == daemon->epoll_fd)
     return MHD_NO;
 #if defined(HTTPS_SUPPORT) && defined(UPGRADE_SUPPORT)
-  if (0 != (MHD_ALLOW_UPGRADE & daemon->options))
+  if (0 != (MHD_USE_UPGRADE & daemon->options))
     {
        daemon->epoll_upgrade_fd = setup_epoll_fd (daemon);
        if (MHD_INVALID_SOCKET == daemon->epoll_upgrade_fd)
@@ -4740,7 +4740,7 @@ MHD_start_daemon_va (unsigned int flags,
   if (0 != (flags & MHD_USE_TCP_FASTOPEN))
     return NULL;
 #endif
-  if (0 != (flags & MHD_ALLOW_UPGRADE))
+  if (0 != (flags & MHD_USE_UPGRADE))
     {
 #ifdef UPGRADE_SUPPORT
       flags |= MHD_USE_SUSPEND_RESUME;
@@ -5449,7 +5449,7 @@ close_all_connections (struct MHD_Daemon *daemon)
   struct MHD_Connection *pos;
   const _MHD_bool used_thr_p_c = (0 != (daemon->options & 
MHD_USE_THREAD_PER_CONNECTION));
 #ifdef UPGRADE_SUPPORT
-  const _MHD_bool upg_allowed = (0 != (daemon->options & MHD_ALLOW_UPGRADE));
+  const _MHD_bool upg_allowed = (0 != (daemon->options & MHD_USE_UPGRADE));
 #endif /* UPGRADE_SUPPORT */
 #if defined(HTTPS_SUPPORT) && defined(UPGRADE_SUPPORT)
   struct MHD_UpgradeResponseHandle *urh;
diff --git a/src/microhttpd/response.c b/src/microhttpd/response.c
index 17fe812..26cae65 100644
--- a/src/microhttpd/response.c
+++ b/src/microhttpd/response.c
@@ -692,7 +692,7 @@ MHD_response_execute_upgrade_ (struct MHD_Response 
*response,
   struct MHD_UpgradeResponseHandle *urh;
   size_t rbo;
 
-  if (0 == (daemon->options & MHD_ALLOW_UPGRADE))
+  if (0 == (daemon->options & MHD_USE_UPGRADE))
     return MHD_NO;
 
   if (NULL ==
diff --git a/src/microhttpd/test_upgrade.c b/src/microhttpd/test_upgrade.c
index fff2d98..7258345 100644
--- a/src/microhttpd/test_upgrade.c
+++ b/src/microhttpd/test_upgrade.c
@@ -61,7 +61,7 @@ test_upgrade (int flags,
 
   done = 0;
 
-  d = MHD_start_daemon (flags | MHD_USE_DEBUG | MHD_ALLOW_UPGRADE,
+  d = MHD_start_daemon (flags | MHD_USE_DEBUG | MHD_USE_UPGRADE,
                         1080,
                         NULL, NULL,
                         &ahc_upgrade, NULL,
diff --git a/src/microhttpd/test_upgrade_ssl.c 
b/src/microhttpd/test_upgrade_ssl.c
index bc4c424..bb3d2c3 100644
--- a/src/microhttpd/test_upgrade_ssl.c
+++ b/src/microhttpd/test_upgrade_ssl.c
@@ -139,7 +139,7 @@ test_upgrade (int flags,
 
   done = 0;
 
-  d = MHD_start_daemon (flags | MHD_USE_DEBUG | MHD_ALLOW_UPGRADE | 
MHD_USE_TLS,
+  d = MHD_start_daemon (flags | MHD_USE_DEBUG | MHD_USE_UPGRADE | MHD_USE_TLS,
                         1080,
                         NULL, NULL,
                         &ahc_upgrade, NULL,


hooks/post-receive
diff --git a/src/include/microhttpd.h b/src/include/microhttpd.h
index 7634897..21d90fa 100644
--- a/src/include/microhttpd.h
+++ b/src/include/microhttpd.h
@@ -690,7 +690,7 @@ enum MHD_FLAG
    * "Upgrade" may require usage of additional internal resources,
    * which we do not want to use unless necessary.
    */
-  MHD_ALLOW_UPGRADE = 32768
+  MHD_USE_UPGRADE = 32768
 
 };
 
@@ -2859,7 +2859,7 @@ enum MHD_FEATURE
 
   /**
    * Get whether HTTP "Upgrade" is supported.
    * If supported then #MHD_ALLOW_UPGRADE, #MHD_upgrade_action() and
    * #MHD_create_response_for_upgrade() can be used.
    */
   MHD_FEATURE_UPGRADE = 17
@@ -2859,7 +2859,7 @@ enum MHD_FEATURE
   /**
    * Get whether HTTP "Upgrade" is supported.
-   * If supported then #MHD_ALLOW_UPGRADE, #MHD_upgrade_action() and
+   * If supported then #MHD_USE_UPGRADE, #MHD_upgrade_action() and
    * #MHD_create_response_for_upgrade() can be used.
    */
-- 
GNU libmicrohttpd



reply via email to

[Prev in Thread] Current Thread [Next in Thread]